"""
Wallet-related tools for the Crypto.com developer platform.
"""

from crypto_com_developer_platform_client import Wallet
from langchain_core.tools import tool


@tool
def create_wallet() -> str:
    """
    Create a new wallet and return its address and private key.

    This function interacts with the Crypto.com developer platform to create a new
    blockchain wallet. It retrieves the wallet's address and private key.

    Returns:
        str: A formatted string containing the wallet's address and private key.

    Example:
        >>> wallet_info = create_wallet()
        >>> print(wallet_info)
        Wallet created! Address: 0x123..., Private Key: abcd...
    """
    wallet = Wallet.create_wallet()
    return f"Wallet created! Address: {wallet['data']['address']}, Private Key: {wallet['data']['privateKey']}"


@tool
def get_wallet_balance(address: str) -> str:
    """
    Get the balance of a wallet.

    This function retrieves the balance of a specified wallet address
    using the Crypto.com developer platform.

    Args:
        address (str): The address to get the balance for (e.g., "xyz.cro").

    Returns:
        str: A formatted string containing the wallet balance.

    Example:
        >>> balance = get_wallet_balance("0x123...")
        >>> print(balance)
        Balance for wallet 0x123...: {...}
    """
    balance = Wallet.get_balance(address)
    return f"Balance for wallet {address}: {balance}"
