"""
Blockchain Config Module.

This module defines the `BlockchainConfig` TypedDict, which represents the
configuration for blockchain-related settings and integrations.
"""

# Third-party imports
from pydantic import BaseModel, Field


class BlockchainConfig(BaseModel):
    """
    TypedDict for Blockchain configuration.

    Attributes:
        chainId (str): The ID of the blockchain to connect to.
        explorer_api_key (str): The API key for the blockchain explorer.

    Example:
        >>> from lib.types.blockchain_config import BlockchainConfig
        >>> blockchain_config: BlockchainConfig = {
        ...     "chainId": "240",
        ...     "explorer_api_key": "blockchain-api-key"
        ... }
    """

    chainId: str
    explorer_api_key: str = Field(alias="explorer-api-key")
    private_key: str = Field(alias="private-key")
